@@ -4,6 +4,8 @@
 import subprocess
 import os.path
 import os
+import glob
+import re
 import shutil
 from .new_control import (NewControl, is_new_control)
 from .control import Control
@@ -20,7 +22,7 @@ class DLPoly:
     __version__ = "4.10"  # which version of dlpoly supports
 
     def __init__(self, control=None, config=None, field=None, statis=None, output=None,
-                 destconfig=None, rdf=None, workdir=None):
+                 destconfig=None, rdf=None, workdir=None, default_name=None):
         # Default to having a control
         self.control = Control()
         self.config = None
@@ -29,6 +31,7 @@ class DLPoly:
         self.statis = None
         self.rdf = None
         self.workdir = workdir
+        self.default_name = "dlprun"
 
         if control is not None:
             self.load_control(control)
@@ -41,6 +44,20 @@ class DLPoly:
         if rdf is not None:
             self.load_rdf(rdf)
 
+        # If we're defaulting to default name
+        # Get last runname + 1 for this one
+        if workdir is None:
+            dirs = glob.glob(f"{self.default_name}*")
+            if dirs:
+                # Get last dir number
+                idx = [int(re.search(dir, '([0-9]+)$').group(0)) for dir in dirs
+                       if re.search(dir, '([0-9]+)$')]
+                newNum = (sorted(idx)[-1]) + 1
+
+                workdir = f"{self.default_name}{newNum}"
+            else:
+                workdir = f"{self.default_name}1"
+
         # Override output
         if output is not None:
             self.control.io_file_output = output
@@ -53,8 +70,6 @@ class DLPoly:
         # Set the path to be: direc/filename, stripping off all unnecessary pathing
         self.control.io_file_statis = os.path.abspath(
             os.path.join(direc, os.path.basename(self.control.io_file_statis)))
-        self.control.io_file_output = os.path.abspath(
-            os.path.join(direc, os.path.basename(self.control.io_file_output)))
         self.control.io_file_revive = os.path.abspath(
             os.path.join(direc, os.path.basename(self.control.io_file_revive)))
         self.control.io_file_revcon = os.path.abspath(
@@ -276,15 +291,17 @@ class DLPoly:
         self.control.write(controlFile)
 
         if outputFile is None:
-            outputFile = self.control.io_file_output
+            if self.control.io_file_output.upper() == "SCREEN":
+                outputFile = None
+            else:
+                outputFile = self.control.io_file_output
+
+        outputFile = f"-o {outputFile}" if outputFile is not None else ""
+
         if numProcs > 1:
-            runCommand = "{0:s} {1:d} {2:s} -c {3:s} -o {4:s}".format(mpi,
-                                                                      numProcs,
-                                                                      dlpexe,
-                                                                      controlFile,
-                                                                      outputFile)
+            runCommand = f"{mpi} {numProcs} {dlpexe} -c {controlFile} {outputFile}"
         else:
-            runCommand = "{0:s} -c {1:s} -o {2:s}".format(dlpexe, controlFile, outputFile)
+            runCommand = f"{dlpexe} -c {controlFile} {outputFile}"
 
         if modules:
             loadMods = "module purge && module load " + modules
